function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { NativeModules, NativeEventEmitter } from 'react-native';

class SocketIO {
  constructor(url, options) {
    _defineProperty(this, "SocketIOModule", void 0);

    _defineProperty(this, "SocketIOCallbacksList", void 0);

    _defineProperty(this, "eventEmitter", void 0);

    this.SocketIOModule = NativeModules.RNSocketIO;
    this.SocketIOCallbacksList = {};
    this.eventEmitter = new NativeEventEmitter(NativeModules.SocketIo);
    this.eventEmitter.addListener('onEventListener', nativeEvent => {
      var _this$SocketIOCallbac;

      (_this$SocketIOCallbac = this.SocketIOCallbacksList[nativeEvent.uniqueID]) === null || _this$SocketIOCallbac === void 0 ? void 0 : _this$SocketIOCallbac.callback(nativeEvent.data);
    });
    this.SocketIOModule.initialize(url, options !== null && options !== void 0 ? options : {}, this._callCallbackResponse);
  }

  _callCallbackResponse(error) {
    if (error) {
      throw error;
    }
  }
  /**
   * Open socket connection.
   */


  connect() {
    this.SocketIOModule.connect();
  }
  /**
   * Close socket connection.
   */


  disconnect() {
    this.SocketIOModule.disconnect();
  }
  /**
   * Send socket event.
   * @param eventName Name of socket event.
   * @param data Data to send on socket event.
   */


  emit(eventName, data) {
    this.SocketIOModule.emit(eventName, {
      data
    });
  }
  /**
   * Listen to socket event.
   * @param eventName Name of socket event.
   * @param callback Callback to listen to socket event.
   */


  on(eventName, callback) {
    this.SocketIOModule.on(eventName, (nativeEventName, uniqueID) => {
      this.SocketIOCallbacksList[uniqueID] = {
        uniqueID,
        eventName: nativeEventName,
        callback
      };
    });
  }
  /**
   * Listen once to socket event.
   * @param eventName Name of socket event.
   * @param callback Callback to listen to socket event.
   */


  once(eventName, callback) {
    this.SocketIOModule.once(eventName, (nativeEventName, uniqueID) => {
      this.SocketIOCallbacksList[uniqueID] = {
        uniqueID,
        eventName: nativeEventName,
        callback
      };
    });
  }
  /**
   * Remove socket event listener.
   * @param eventName Name of socket event.
   * @param callback Callback of registered socket event.
   */


  off(eventName, callback) {
    let keyToDelete = null;

    for (const key of Object.keys(this.SocketIOCallbacksList)) {
      const listItem = this.SocketIOCallbacksList[key];

      if (listItem.eventName === eventName && listItem.callback === callback) {
        keyToDelete = listItem.uniqueID;
        this.SocketIOModule.off(eventName, keyToDelete);
        break;
      }
    }

    if (keyToDelete) {
      delete this.SocketIOCallbacksList[keyToDelete];
    }
  }
  /**
   * Get connection status of socket.
   * @param callback Callback with connection status of socket.
   */


  connected(callback) {
    this.SocketIOModule.connected(callback);
  }
  /**
   * Get id of socket.
   * @param callback Callback with id of socket.
   */


  getId(callback) {
    this.SocketIOModule.getId(callback);
  }
  /**
   * Get connection status of socket.
   * Warning: this method are synchronous blocking UI, use it carefully.
   */


  connectedSync() {
    return this.SocketIOModule.connectedSync();
  }
  /**
   * Get id of socket.
   * Warning: this method are synchronous blocking UI, use it carefully.
   */


  getIdSync() {
    return this.SocketIOModule.getIdSync();
  }

  static serializeQuery(object) {
    let str = [];

    for (const p in object) if (object.hasOwnProperty(p)) {
      str.push(encodeURIComponent(p) + '=' + encodeURIComponent(object[p]));
    }

    return str.join('&');
  }

}

export default SocketIO;
//# sourceMappingURL=index.js.map